# coding=utf-8
# Time:2023-4-27 10:50
# 此脚本为Ubuntu系统的基线检测和修复

import os
import pwd
from traceback import format_exc
import shutil

class check():
    def __init__(self):
        self.func_result = []

    def Max_User_Loggin(self):
        result = {}
        result["value"] = "update_max_user_loggin"
        result["msg"] = "确保SSH MaxAuthTries设置为4或更低(小)"
        num = 0
        try:
            with open("/etc/ssh/sshd_config") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line.startswith("MaxAuthTries 4"):
                        num += 1
            if num > 0:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    # def password_lock(self):
    #     result = {}
    #     result["value"] = "update_password_lock"
    #     result["msg"] = "确保配置了密码尝试失败的锁定"
    #     password_auth_num = 0
    #     try:
    #         with open("/etc/pam.d/common-auth") as f:
    #             for line in f.readlines():
    #                 line = line.strip()
    #                 if line == "auth required pam_tally2.so onerr=fail audit silent deny=5 unlock_time=900":
    #                     password_auth_num += 1
    #         with open("/etc/pam.d/common-account") as f:
    #             for line in f.readlines():
    #                 line = line.strip()
    #                 if line == "account requisite pam_deny.so" or line == "account required pam_tally2.so":
    #                     password_auth_num += 1
    #         if password_auth_num == 3:
    #             result["code"] = 0
    #         else:
    #             result["code"] = 1
    #     except:
    #         result["code"] = 1
    #     self.func_result.append(result)

    def Ssh_Time_Out(self):
        result = {}
        result["value"] = "update_ssh_timeout"
        result["msg"] = "确保已配置SSH空闲超时间隔"
        num = 0
        try:
            with open("/etc/ssh/sshd_config") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "ClientAliveInterval 300" or line == "ClientAliveCountMax 0":
                        num += 1
            if num == 2:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def User_Shell_Tmout(self):
        result = {}
        result["value"] = "update_shell_TMOUT"
        result["msg"] = "确保默认用户shell超时为900秒或更短"
        num = 0
        try:
            with open("/etc/profile") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "TMOUT=600":
                        num += 1
            with open("/etc/bash.bashrc") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "TMOUT=600":
                        num += 1
            if num == 2:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def User_Null_Pass(self):
        result = {}
        result["value"] = "update_user_null_pass"
        result["msg"] = "确保密码字段不为空"
        num = 0
        try:
            with open("/etc/shadow") as f:
                for line in f.readlines():
                    line = line.strip().split(":")
                    if line[1] == "":
                        num += 1
            if num == 0:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Disable_UserPass_Reuse(self):
        result = {}
        result["value"] = "update_disable_userpass_reuse"
        result["msg"] = "确保限制密码重用"
        num = 0
        try:
            with open("/etc/pam.d/common-password") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "password required pam_pwhistory.so remember=5":
                        num += 1
            if num == 1:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Disable_Null_PassLoggin(self):
        result = {}
        result["value"] = "update_no_passwd"
        result["msg"] = "确保已禁用SSH空密码登录"
        num = 0
        try:
            with open("/etc/ssh/sshd_config") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "PermitEmptyPasswords no":
                        num += 1
            if num > 0:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Passwd_File_Mode(self):
        result = {}
        result["value"] = "update_passwd_file_sys6"
        result["msg"] = "确保已配置/etc/passwd-的权限"
        try:
            # passwd和备份文件passwd-的权限都需要调整
            passwd_file_user = pwd.getpwuid(os.stat('/etc/passwd').st_uid)[0]
            passwd_file_limits = os.popen("stat -c %a /etc/passwd").read()
            passwd_bakfile_user = pwd.getpwuid(os.stat('/etc/passwd-').st_uid)[0]
            passwd_bakfile_limits = os.popen("stat -c %a /etc/passwd-").read()
            if passwd_file_user == "root" and int(passwd_file_limits.strip('\n')) <= 644 and passwd_bakfile_user == "root" and int(passwd_bakfile_limits.strip('\n')) <= 644:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Group_File_Mode(self):
        result = {}
        result["value"] = "update_group_file_sys6"
        result["msg"] = "确保已配置/etc/group-的权限"
        try:
            group_file_user = pwd.getpwuid(os.stat('/etc/group').st_uid)[0]
            group_bakfile_user = pwd.getpwuid(os.stat('/etc/group').st_uid)[0]
            group_file_limits = os.popen("stat -c %a /etc/group-").read()
            group_bakfile_limits = os.popen("stat -c %a /etc/group-").read()
            if group_file_user == "root" and int(group_file_limits.strip('\n')) <= 644 and group_bakfile_user == "root" and int(group_bakfile_limits.strip('\n')) <= 644:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    # def disable_prelink(self):
    #     result = {}
    #     result["value"] = "update_disable_prelink"
    #     result["msg"] = "确保禁用prelink"
    #     try:
    #         cmd_result = os.popen("dpkg -l |grep -w prelink |wc -l")
    #         num = cmd_result.read().strip()
    #         if num == 0:
    #             result["code"] = 0
    #         else:
    #             result["code"] = 1
    #     except:
    #         result["code"] = 1
    #     self.func_result.append(result)

    def Open_ASLR(self):
        result = {}
        result["value"] = "update_open_ASLR"
        result["msg"] = "确保启用了地址空间布局随机化（ASLR）"
        num = 0
        try:
            with open("/etc/sysctl.conf") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "kernel.randomize_va_space = 2":
                        num += 1
            cmd_result = os.popen("sysctl -a |grep kernel.randomize_va_space")
            if cmd_result.read().strip().split("=")[1].strip() == "2":
                num += 1
            if num == 2:
                result["code"] = 0
            else:
                result["code"] = 1
        except Exception as e:
            print(e)
        self.func_result.append(result)

    def User_And_Group_ShadowFileMode(self):
        result = {}
        result["value"] = "update_user_and_group_shadowfilemode"
        result["msg"] = "确保已配置/etc/shadow和/etc/gshadow的权限"
        try:
            # 用户shadow和组shadow文件、备份文件的权限都需要调整
            user_shadow_file = pwd.getpwuid(os.stat('/etc/shadow').st_uid)[0]
            user_shadow_file_limits = os.popen("stat -c %a /etc/shadow").read()
            user_shadow_bakfile = pwd.getpwuid(os.stat('/etc/shadow-').st_uid)[0]
            user_shadow_bakfile_limits = os.popen("stat -c %a /etc/shadow-").read()
            group_shadow_file = pwd.getpwuid(os.stat('/etc/gshadow').st_uid)[0]
            group_shadow_file_limits = os.popen("stat -c %a /etc/gshadow").read()
            group_shadow_bakfile = pwd.getpwuid(os.stat('/etc/gshadow-').st_uid)[0]
            group_shadow_bakfile_limits = os.popen("stat -c %a /etc/gshadow-").read()
            if user_shadow_file == "root" and int(user_shadow_file_limits.strip('\n')) <= 640 and group_shadow_file == "root" and int(group_shadow_file_limits.strip('\n')) <= 640 and user_shadow_bakfile == "root" and int(user_shadow_bakfile_limits.strip('\n')) <= 640 and group_shadow_bakfile == "root" and int(group_shadow_bakfile_limits.strip('\n')) <= 640:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Grub_File_Mode(self):
        result = {}
        result["value"] = "update_grub_file_user_sys"
        result["msg"] = "确保配置了bootloader配置的权限"
        try:
            user = pwd.getpwuid(os.stat('/boot/grub/grub.cfg').st_uid)[0]
            limits = os.popen("stat -c %a /boot/grub/grub.cfg").read()
            if user == "root" and int(limits.strip('\n')) <= 400:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Save_Change_User_Group_Info(self):
        result = {}
        result["value"] = "update_user_group_log_sys"
        result["msg"] = "确保收集了修改用户/组信息的事件"
        num = 0
        try:
            with open("/etc/audit/rules.d/audit.rules") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "-w /etc/group -p wa -k identity" or line == "-w /etc/passwd -p wa -k identity" or line == "-w /etc/gshadow -p wa -k identity" or line == "-w /etc/shadow -p wa -k identity" or line == "-w /etc/security/opasswd -p wa -k identity":
                        num += 1
            if num == 5:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Save_Sudo_Log(self):
        result = {}
        result["value"] = "update_scope_log_sys"
        result["msg"] = "确保系统管理范围（sudoers）更改的收集"
        num = 0
        try:
            with open("/etc/audit/rules.d/audit.rules") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "-w /etc/sudoers -p wa -k scope" or line == "-w /etc/sudoers.d/ -p wa -k scope":
                        num += 1
            if num == 2:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Audit_Conf_Unchanged(self):
        result = {}
        result["value"] = "update_audit_conf_no_auditctl_sys"
        result["msg"] = "确保审核配置是不变的"
        num = 0
        try:
            with open("/etc/audit/rules.d/audit.rules") as f:
                for line in f.readlines():
                    if line.strip() == "-e 2":
                        num += 1
            if num == 1:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Save_Session_loggings_Log(self):
        result = {}
        result["value"] = "update_session_loggings_sys"
        result["msg"] = "确保收集了会话启动信息"
        num = 0
        try:
            with open("/etc/audit/rules.d/audit.rules") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "-w /var/run/utmp -p wa -k session" or line == "-w /var/log/wtmp -p wa -k logins" or line == "-w /var/log/btmp -p wa -k logins":
                        num += 1
            if num == 3:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Log_No_AutoDel(self):
        result = {}
        result["value"] = "update_max_log_no_del"
        result["msg"] = "确保审核日志不会自动删除"
        num = 0
        try:
            with open("/etc/audit/auditd.conf") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "max_log_file_action = keep_logs":
                        num += 1
            if num == 1:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Save_Os_Wirte_Log(self):
        result = {}
        result["value"] = "update_selinux_wirte_sys"
        result["msg"] = "确保收集了修改系统的强制访问控制的事件"
        num = 0
        try:
            with open("/etc/audit/rules.d/audit.rules") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "-w /etc/apparmor/ -p wa -k MAC-policy" or line == "-w /etc/apparmor.d/ -p wa -k MAC-policy":
                        num += 1
            if num == 2:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Save_Logging_Exit_Log(self):
        result = {}
        result["value"] = "update_logging_exit_log_sys"
        result["msg"] = "确保收集了登录和注销事件"
        num = 0
        try:
            with open("/etc/audit/rules.d/audit.rules") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line == "-w /var/log/faillog -p wa -k logins" or line == "-w /var/log/lastlog -p wa -k logins" or line == "-w /var/log/tallylog -p wa -k logins":
                        num += 1
            if num == 3:
                result["code"] = 0
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Close_Cron_SendMail(self):
        result = {}
        result["value"] = "update_close_cron_mail"
        result["msg"] = "确保定时任务不发送邮件"
        num = 0
        try:
            if os.path.exists("/etc/crontab"):
                with open("/etc/crontab") as f:
                    for line in f.readlines():
                        line = line.strip()
                        if line == 'MAILTO=""':
                            num += 1
                if num == 1:
                    result["code"] = 0
                else:
                    result["code"] = 1
            else:
                result["code"] = 1
        except:
            result["code"] = 1
        self.func_result.append(result)

    def Check_Umask(self):
        result = {}
        result["value"] = "update_check_umask"
        result["msg"] = "确保默认用户umask限制为027或更高"
        num = 0
        try:
            with open("/etc/profile") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line.startswith("umask"):
                        if int(line.split(" ")[1]) >= 27:
                            num += 1
            with open("/etc/bash.bashrc") as f:
                for line in f.readlines():
                    line = line.strip()
                    if line.startswith("umask"):
                        if int(line.split(" ")[1]) >= 27:
                            num += 1
            if num == 2:
                result["code"] = 0
            else:
                result["code"] = 1
        except Exception as e:
            result["code"] = 1
        self.func_result.append(result)

    def check_baseline(self):
        try:
            self.Max_User_Loggin()
            # self.password_lock
            self.Ssh_Time_Out()
            self.User_Shell_Tmout()
            self.User_Null_Pass()
            self.Disable_UserPass_Reuse()
            self.Disable_Null_PassLoggin()
            self.Passwd_File_Mode()
            self.Group_File_Mode()
            # self.disable_prelink()
            self.Open_ASLR()
            self.User_And_Group_ShadowFileMode()
            self.Grub_File_Mode()
            self.Save_Change_User_Group_Info()
            self.Save_Sudo_Log()
            self.Audit_Conf_Unchanged()
            self.Save_Session_loggings_Log()
            self.Log_No_AutoDel()
            self.Save_Os_Wirte_Log()
            self.Save_Logging_Exit_Log()
            self.Close_Cron_SendMail()
            self.Check_Umask()
            return self.func_result
        except:
            print(format_exc())

    def update_option(self,param):
        result = {}
        func_name = param['func_name']
        try:
            agentClass = update_opetion()
            if hasattr(agentClass, func_name) == True:
                mtd = getattr(agentClass, func_name)
                if mtd() == 0:
                    result["msg"] = func_name
                    result["code"] = 0
                else:
                    result["msg"] = func_name
                    result["code"] = 1
        except:
            result["msg"] = func_name
            result["code"] = 1
        return result

class update_opetion():

    def __init__(self):
        self.result = ''

    def update_max_user_loggin(self):
        try:
            result1 = os.system("/usr/bin/cp /etc/ssh/sshd_config /etc/ssh/sshd_config.bak")
            result2 = os.system("sed -i '/^MaxAuthTries/d' /etc/ssh/sshd_config && echo 'MaxAuthTries 4' >> /etc/ssh/sshd_config && systemctl restart sshd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    # def update_password_lock(self):
    #     try:
    #         os.system("cp /etc/pam.d/common-auth /etc/pam.d/common-auth.bak")
    #         auth_file = os.system("sed -i '/^auth.*required.*pam_tally2.so.*onerr=fail.*audit.*silent.*deny=.*unlock_time=.*$/d' /etc/pam.d/common-auth &&  echo 'auth required pam_tally2.so onerr=fail audit silent deny=5 unlock_time=900' >> /etc/pam.d/common-auth")
    #         os.system("cp etc/pam.d/common-account /etc/pam.d/common-account.bak")
    #         account_file = os.system("sed -i '/^account.*requisite.*pam_deny.so\|^account.*required.*pam_tally2.so/d' /etc/pam.d/common-account && echo  'account requisite pam_deny.so\naccount required pam_tally2.so' >> /etc/pam.d/common-account")
    #         if auth_file == 0 and account_file == 0:
    #             return 0
    #         else:
    #             return 1
    #     except:
    #         return 1

    def update_ssh_timeout(self):
        try:
            shutil.copy("/etc/ssh/sshd_config", "/etc/ssh/sshd_config.bak")
            result = os.system("""sed -i '/^ClientAliveInterval/d; /^ClientAliveCountMax/d' /etc/ssh/sshd_config  && echo 'ClientAliveInterval 300\nClientAliveCountMax 0' >> /etc/ssh/sshd_config && systemctl restart sshd""")
            if result == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_shell_TMOUT(self):
        try:
            shutil.copy("/etc/profile", "/etc/profile.bak")
            shutil.copy("/etc/bash.bashrc", "/etc/bash.bashrc.bak")
            result1 = os.system(""" sed -i '/^export TMOUT\|^TMOUT/d' /etc/bash.bashrc && sed -i '/^export TMOUT\|^TMOUT/d' /etc/profile""")
            result2 = os.system("""echo 'TMOUT=600' >> /etc/profile && echo 'TMOUT=600' >> /etc/bash.bashrc""")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_user_null_pass(self):
        try:
            with open("/etc/shadow") as f:
                for line in f.readlines():
                    line = line.strip().split(":")
                    if line[1] == "":
                        user_name = line[0]
            if os.system("passwd -l %s" %user_name) == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_disable_userpass_reuse(self):
        try:
            shutil.copy("/etc/pam.d/common-password", "/etc/pam.d/common-password.bak")
            result = os.system("""sed -i '/^password.*required.*pam_pwhistory.so.*remember=.*/d' /etc/pam.d/common-password  && echo 'password required pam_pwhistory.so remember=5' >> /etc/pam.d/common-password""")
            if result == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_no_passwd(self):
        try:
            shutil.copy("/etc/ssh/sshd_config", "/etc/ssh/sshd_config.bak")
            result = os.system("sed -i '/^PermitEmptyPasswords/d' /etc/ssh/sshd_config && echo 'PermitEmptyPasswords no' >> /etc/ssh/sshd_config && systemctl restart sshd")
            if result == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_passwd_file_sys6(self):
        try:
            result1 = os.system("chown root:root /etc/passwd- && chmod u-x,go-wx /etc/passwd-")
            result2 = os.system("chown root:root /etc/passwd && chmod u-x,go-wx /etc/passwd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_group_file_sys6(self):
        try:
            result1 = os.system("chown root:root /etc/group- && chmod u-x,go-wx /etc/group-")
            result2 = os.system("chown root:root /etc/group && chmod u-x,go-wx /etc/group")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    # def update_disable_prelink(self):
    #     try:
    #         result = os.system("apt purge prelink")
    #         if result == 0:
    #             return 0
    #         else:
    #             return 1
    #     except:
    #         return 1

    def update_open_ASLR(self):
        try:
            shutil.copy("/etc/sysctl.conf", "/etc/sysctl.conf.bak")
            result = os.system("sed -i '/^.*os一致化：确保启用了地址空间布局随机化（ASLR）\|^kernel.randomize_va_space/d' /etc/sysctl.conf && echo '\n# 确保启用了地址空间布局随机化（ASLR）\nkernel.randomize_va_space = 2' >> /etc/sysctl.conf && sysctl -p")
            os.system("""
            for file in /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/ sysctl.d/*.conf /usr/local/lib/sysctl.d/*.conf /run/sysctl.d/*.conf%3B
            do
	            if [ -f "$file" ]; then
	                cp $file ${file}.bak
		            grep -Esq "^\s*kernel\.randomize_va_space\s*=\s*([0-1]|[3-9]|[1-9][0-9]+)" "$file" && sed -ri 's/^\s*kernel\.randomize_va_space\s*=\s*([0-1]|[3-9]|[1-9][0-9]+)/# %26 /gi' "$file"
                fi
            done""")
            if result == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_user_and_group_shadowfilemode(self):
        try:
            result1 = os.system("chown root:root /etc/shadow && chmod u-x,g-wx,o-rwx /etc/shadow && chown root:root /etc/shadow- && chmod u-x,g-wx,o-rwx /etc/shadow-")
            result2 = os.system("chown root:root /etc/gshadow && chmod u-x,g-wx,o-rwx /etc/gshadow && chown root:root /etc/gshadow-  && chmod u-x,g-wx,o-rwx /etc/gshadow-")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_grub_file_user_sys(self):
        try:
            result = os.system("chown root:root /boot/grub/grub.cfg && chmod u-wx,og-rwx /boot/grub/grub.cfg")
            if result == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_user_group_log_sys(self):
        try:
            shutil.copy("/etc/audit/rules.d/audit.rules", "/etc/audit/rules.d/audit.rules.bak")
            result1 = os.system("sed -i '/^.*os一致化：确保收集了修改用户\/组信息的事件\|^-w.*\/etc\/group.*-p.*wa.*-k.*\|^-w.*\/etc\/passwd.*-p.*wa.*-k.*\|^-w.*\/etc\/gshadow.*-p.*wa.*-k.*\|^-w.*\/etc\/shadow.*-p.*wa.*-k.*\|^-w.*\/etc\/security\/opasswd.*-p.*wa.*-k.*/d' /etc/audit/rules.d/audit.rules")
            result2 = os.system("echo '\n# os一致化：确保收集了修改用户/组信息的事件\n-w /etc/group -p wa -k identity\n-w /etc/passwd -p wa -k identity\n-w /etc/gshadow -p wa -k identity\n-w /etc/shadow -p wa -k identity\n-w /etc/security/opasswd -p wa -k identity' >> /etc/audit/rules.d/audit.rules && systemctl restart auditd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_scope_log_sys(self):
        try:
            shutil.copy("/etc/audit/rules.d/audit.rules", "/etc/audit/rules.d/audit.rules.bak")
            result1 = os.system("sed -i '/^.*os一致化：确保系统管理范围（sudoers）更改的收集\|^-w.*\/etc\/sudoers.*-p.*wa.*-k.*\|^-w.*\/etc\/sudoers.d\/.*-p.*wa.*-k.*/d' /etc/audit/rules.d/audit.rules")
            result2 = os.system("echo '\n# os一致化：确保系统管理范围（sudoers）更改的收集\n-w /etc/sudoers -p wa -k scope\n-w /etc/sudoers.d/ -p wa -k scope' >> /etc/audit/rules.d/audit.rules && systemctl restart auditd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_audit_conf_no_auditctl_sys(self):
        try:
            shutil.copy("/etc/audit/rules.d/audit.rules", "/etc/audit/rules.d/audit.rules.bak")
            result1 = os.system("sed -i '/^.*os一致化：确保审核配置是不变的\|^-e.*/d' /etc/audit/rules.d/audit.rules")
            result2 = os.system("echo '\n# os一致化：确保审核配置是不变的\n-e 2' >> /etc/audit/rules.d/audit.rules && systemctl restart auditd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_session_loggings_sys(self):
        try:
            shutil.copy("/etc/audit/rules.d/audit.rules", "/etc/audit/rules.d/audit.rules.bak")
            result1 = os.system("sed -i '/^.*os一致化：确保收集了会话启动信息\|^-w.*\/var\/run\/utmp.*-p.*wa.*-k.*\|^-w.*\/var\/log\/wtmp.*-p.*wa.*-k.*\|^-w.*\/var\/log\/btmp.*-p.*wa.*-k.*/d' /etc/audit/rules.d/audit.rules")
            result2 = os.system("echo '\n# os一致化：确保收集了会话启动信息\n-w /var/run/utmp -p wa -k session\n-w /var/log/wtmp -p wa -k logins\n-w /var/log/btmp -p wa -k logins' >> /etc/audit/rules.d/audit.rules && systemctl restart auditd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_max_log_no_del(self):
        try:
            shutil.copy("/etc/audit/auditd.conf", "/etc/audit/auditd.conf.bak")
            result = os.system("sed -i '/^.*os一致化：确保审核日志不会自动删除\|^max_log_file_action/d' /etc/audit/auditd.conf && echo '\n# os一致化：确保审核日志不会自动删除\nmax_log_file_action = keep_logs' >> /etc/audit/auditd.conf")
            if result == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_selinux_wirte_sys(self):
        try:
            shutil.copy("/etc/audit/rules.d/audit.rules", "/etc/audit/rules.d/audit.rules.bak")
            result1 = os.system("sed -i '/^.*os一致化：确保收集了修改系统的强制访问控制的事件\|^-w.*\/etc\/apparmor\/.*-p.*wa.*-k.*\|^-w.*\/etc\/apparmor.d\/.*-p.*wa.*-k.*/d' /etc/audit/rules.d/audit.rules")
            result2 = os.system("echo '\n# os一致化：确保收集了修改系统的强制访问控制的事件\n-w /etc/apparmor/ -p wa -k MAC-policy\n-w /etc/apparmor.d/ -p wa -k MAC-policy' >> /etc/audit/rules.d/audit.rules && systemctl restart auditd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_logging_exit_log_sys(self):
        try:
            shutil.copy("/etc/audit/rules.d/audit.rules", "/etc/audit/rules.d/audit.rules.bak")
            result1 = os.system("sed -i '/^.*os一致化：确保收集了登录和注销事件\|^-w.*\/var\/log\/faillog.*-p.*wa.*-k.*\|^-w.*\/var\/log\/lastlog.*-p.*wa.*-k.*\|^-w.*\/var\/log\/tallylog.*-p.*wa.*-k.*/d' /etc/audit/rules.d/audit.rules")
            result2 = os.system("echo '\n# os一致化：确保收集了登录和注销事件\n-w /var/log/faillog -p wa -k logins\n-w /var/log/lastlog -p wa -k logins\n-w /var/log/tallylog -p wa -k logins' >> /etc/audit/rules.d/audit.rules && systemctl restart auditd")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_close_cron_mail(self):
        try:
            result = os.system("""sed -i '/^MAILTO=/d' /etc/crontab && sed -i '/SHELL/aMAILTO=""' /etc/crontab && systemctl restart cron""")
            if result == 0:
                return 0
            else:
                return 1
        except:
            return 1

    def update_check_umask(self):
        try:
            result1 = os.system("""sed -i '/^umask/d' /etc/profile && echo 'umask 027' >>/etc/profile && source /etc/profile""")
            result2 = os.system("""sed -i '/^umask/d' /etc/bash.bashrc && echo 'umask 027' >>/etc/bash.bashrc && source /etc/bash.bashrc""")
            if result1 == 0 and result2 == 0:
                return 0
            else:
                return 1
        except:
            return 1

if __name__ == '__main__':
   pass
